@@ -37,7 +37,7 @@ class Tensor:
 
     """
 
-    def __init__(self, x, δx=None, Δx=None, Δδx=None, ntrax=2):
+    def __init__(self, x, δx=None, Δx=None, Δδx=None, ntrax=0):
         """Init a Hyper-Dual Tensor with trailing axes.
 
         Parameters
@@ -75,6 +75,11 @@ class Tensor:
             value = value.reshape([*self.shape, *np.ones(self.ntrax, dtype=int)])
         return value
 
+    def __neg__(self):
+        return Tensor(
+            x=-self.x, δx=-self.δx, Δx=-self.Δx, Δδx=-self.Δδx, ntrax=self.ntrax
+        )
+
     def __add__(self, B):
         A = self
         if isinstance(B, Tensor):
@@ -87,7 +92,7 @@ class Tensor:
             δx = δ(A)
             Δx = Δ(A)
             Δδx = Δδ(A)
-        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx)
+        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx, ntrax=A.ntrax)
 
     def __sub__(self, B):
         A = self
@@ -101,7 +106,7 @@ class Tensor:
             δx = δ(A)
             Δx = Δ(A)
             Δδx = Δδ(A)
-        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx)
+        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx, ntrax=A.ntrax)
 
     def __mul__(self, B):
         A = self
@@ -115,14 +120,16 @@ class Tensor:
             δx = δ(A) * B
             Δx = Δ(A) * B
             Δδx = Δδ(A) * B
-        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx)
+        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx, ntrax=A.ntrax)
 
     def __truediv__(self, B):
         A = self
         if isinstance(B, Tensor):
             raise NotImplementedError("Divide by Tensor is not supported.")
         else:
-            return Tensor(x=f(A) / B, δx=δ(A) / B, Δx=Δ(A) / B, Δδx=Δδ(A) / B)
+            return Tensor(
+                x=f(A) / B, δx=δ(A) / B, Δx=Δ(A) / B, Δδx=Δδ(A) / B, ntrax=A.ntrax
+            )
 
     def __pow__(self, p):
         A = self
@@ -130,7 +137,7 @@ class Tensor:
         δx = p * f(A) ** (p - 1) * δ(A)
         Δx = p * f(A) ** (p - 1) * Δ(A)
         Δδx = p * f(A) ** (p - 1) * Δδ(A) + p * (p - 1) * f(A) ** (p - 2) * δ(A) * Δ(A)
-        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx)
+        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx, ntrax=A.ntrax)
 
     def T(self):
         return transpose(self)
@@ -143,6 +150,7 @@ class Tensor:
     __rmul__ = __mul__
     __rmatmul__ = __matmul__
     __rtruediv__ = __truediv__
+    __array_ufunc__ = None
 
 
 def einsum2(subscripts, *operands):
@@ -165,7 +173,7 @@ def einsum2(subscripts, *operands):
             δx = _einsum(δ(A), B)
             Δx = _einsum(Δ(A), B)
             Δδx = _einsum(Δδ(A), B)
-        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx)
+        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx, ntrax=A.ntrax)
     else:
         return _einsum(*operands)
 
@@ -179,7 +187,7 @@ def einsum1(subscripts, *operands):
         δx = _einsum(δ(A))
         Δx = _einsum(Δ(A))
         Δδx = _einsum(Δδ(A))
-        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx)
+        return Tensor(x=x, δx=δx, Δx=Δx, Δδx=Δδx, ntrax=A.ntrax)
     else:
         return _einsum(*operands)
 
