@@ -8,21 +8,18 @@ r"""
                                 ╚═╝   ╚═╝  ╚═╝╚═╝  ╚═╝╚═╝  ╚═╝  
 """
 
-from ._array import det as _det, inv as _inv, eye as _eye
-from ._tensor import (
+from . import _linalg as linalg
+from ._math_tensor import (
+    sin,
+    cos,
+    tan,
+    tanh,
     dot,
     ddot,
     trace,
     transpose,
     sum,
     sqrt,
-    det,
-    eigvalsh,
     einsum,
     matmul,
-    function,
-    gradient,
-    hessian,
-    gradient_vector_product,
-    hessian_vector_product,
 )
