@@ -6,33 +6,50 @@ import numpy as np
 def neo_hooke(F):
     C = F.T() @ F
     I1 = tm.trace(C)
-    J = tm.det(F)
+    J = tm.linalg.det(F)
     return (J ** (-2 / 3) * I1 - 3) / 2
 
 
 def ogden(F, mu=1, alpha=2):
     C = F.T() @ F
-    J = tm.det(F)
-    λ = tm.sqrt(tm.eigvalsh(J ** (-2 / 3) * C))
+    J = tm.linalg.det(F)
+    λ = tm.sqrt(tm.linalg.eigvalsh(J ** (-2 / 3) * C))
     return tm.sum(1 / alpha * (λ**alpha - 1))
 
 
+def trig(F):
+    C = F.T() @ F
+    I1 = tm.trace(C)
+    return tm.sin(I1) + tm.cos(I1) + tm.tan(I1) + tm.tanh(I1)
+
+
 def test_function_gradient_hessian():
 
     F = (np.eye(3).ravel() + np.arange(9) / 10).reshape(3, 3, 1, 1)
 
-    for fun in [neo_hooke, ogden]:
-        ww = tr.function(fun, ntrax=2)(F)
-        dwdf, w = tr.gradient(fun, ntrax=2)(F)
-        d2WdF2, dWdF, W = tr.hessian(fun, ntrax=2)(F)
+    for parallel in [False, True]:
+        for fun in [neo_hooke, ogden]:
+            ww = tr.function(fun, ntrax=2, parallel=parallel)(F)
+            dwdf, w = tr.gradient(fun, ntrax=2, parallel=parallel)(F)
+            d2WdF2, dWdF, W = tr.hessian(fun, ntrax=2, parallel=parallel)(F)
+    
+            assert W.shape == (1, 1)
+            assert dWdF.shape == (3, 3, 1, 1)
+            assert d2WdF2.shape == (3, 3, 3, 3, 1, 1)
+    
+            assert np.allclose(w, ww)
+            assert np.allclose(w, W)
+            assert np.allclose(dwdf, dWdF)
 
-        assert W.shape == (1, 1)
-        assert dWdF.shape == (3, 3, 1, 1)
-        assert d2WdF2.shape == (3, 3, 3, 3, 1, 1)
 
-        assert np.allclose(w, ww)
-        assert np.allclose(w, W)
-        assert np.allclose(dwdf, dWdF)
+def test_trig():
+
+    F = (np.eye(3).ravel() + np.arange(9) / 10).reshape(3, 3)
+
+    for fun in [trig]:
+        ww = tr.function(fun)(F)
+        dwdf, w = tr.gradient(fun)(F)
+        d2WdF2, dWdF, W = tr.hessian(fun)(F)
 
 
 def test_repeated_eigvals():
@@ -83,3 +100,4 @@ def test_repeated_eigvals():
 if __name__ == "__main__":
     test_function_gradient_hessian()
     test_repeated_eigvals()
+    test_trig()
